package dk.skat.security.providers.atn;

import dk.skat.begrebsmodel.x2009.x01.x15.*;
import dk.skat.begrebsmodel.xml.schemas.kontekst.x2007.x05.x31.HovedOplysningerDocument;
import dk.skat.begrebsmodel.xml.schemas.kontekst.x2007.x05.x31.HovedOplysningerSvarDocument;
import dk.skat.begrebsmodel.xml.schemas.kontekst.x2007.x05.x31.HovedOplysningerType;
import dk.skat.begrebsmodel.xml.schemas.kontekst.x2007.x05.x31.SvarReaktionType;
import dk.skat.ics.security.EORIVirksomhedSamlingHentService;
import dk.skat.ics.security.EORIVirksomhedSamlingHentServicePortType;
import dk.skat.ics.security.EORIVirksomhedSamlingHentService_Impl;
import weblogic.logging.NonCatalogLogger;

import javax.xml.rpc.ServiceException;
import java.rmi.RemoteException;

/**
 * EORI Number Validator Class.
 * <p/>
 * Makes call to the PS_EORI_VirksomhedSamlingHent service
 *
 * @author Christopher Derek Curry, KrisPoint A/S, cdcurry@krispoint.com
 * @since 1.0
 */
public class EORINumberValidator {

    /**
     * Logger
     */
    private final static NonCatalogLogger logger = new NonCatalogLogger(EORINumberValidator.class.getName());

    public static boolean validateEORINumber(String eori, String endPoint) {

        // Assume false.
        boolean result = false;

        try {
            EORIVirksomhedSamlingHentService service = new EORIVirksomhedSamlingHentService_Impl(endPoint);
            EORIVirksomhedSamlingHentServicePortType port = service.getEORIVirksomhedSamlingHentServicePortType();
            EORIVirksomhedSamlingHentIDocument input = EORIVirksomhedSamlingHentIDocument.Factory.newInstance();
            EORIVirksomhedSamlingHentIType eoriVirksomhedSamlingHentI = input.addNewEORIVirksomhedSamlingHentI();
            EORIVirksomhedSamlingHentIType.EORINummerSamling eoriNummerSamling = eoriVirksomhedSamlingHentI.addNewEORINummerSamling();
            eoriNummerSamling.addØkonomiskOperatørEORINummer(eori);
            KontekstType kontekstTypeInput = KontekstType.Factory.parse(
                    HovedOplysningerDocumentFactory.getHovedOplysningerDocument("ICSAuthenticationProvider",
                            "SecurityProvider", "SecurityProvider").toString());
            eoriVirksomhedSamlingHentI.setKontekst(kontekstTypeInput);
            logger.debug("INPUT: " + input);
            EORIVirksomhedSamlingHentODocument output = port.getEORIVirksomhedSamlingHent(input);
            KontekstType kontekstTypeOutput = output.getEORIVirksomhedSamlingHentO().getKontekst();
            /*
            HovedOplysningerSvarDocument svarDoc = HovedOplysningerSvarDocument.Factory.parse(kontekstTypeOutput + "");
            List<SvarReaktionType> reaktionList = svarDoc.getHovedOplysningerSvar().getSvarReaktionList();
            for (SvarReaktionType svarType : reaktionList) {
                if (svarType.isSetFejl()) {
                    // If there is an error, then bail out of here and do not provide access.
                    return false;
                }
            }
            */
            logger.debug("OUTPUT" + output);

            if (output.getEORIVirksomhedSamlingHentO().getEORIVirksomhedSamling() == null) {
                return false;
            }

            if (output.getEORIVirksomhedSamlingHentO().getEORIVirksomhedSamling().sizeOfEORIVirksomhedArray() == 1) {
                EORIVirksomhedSamlingHentOType.EORIVirksomhedSamling.EORIVirksomhed resultEoriVirk = output.getEORIVirksomhedSamlingHentO().getEORIVirksomhedSamling().getEORIVirksomhedArray(0);
                if (eori.equals(resultEoriVirk.getØkonomiskOperatørEORINummer())) {
                    return true;
                }
            }

        } catch (RemoteException e) {
            logger.error("Error while validating EORI number. Will validate to false.", e);
        } catch (ServiceException e2) {
            logger.error("Error while validating EORI number. Will validate to false.", e2);
        } catch (Exception e3) {
            logger.error("Error while validating EORI number. Will validate to false.", e3);
        }

        return result;

    }


    public static void main(String[] args) {
        boolean x = validateEORINumber("DK82001417", "http://sktdics04esb01.csc.dk:7013/EORI/EORIVirksomhedSamlingHentService?wsdl");
    }


}
