package dk.skat.security.providers.atn;

import dk.skat.begrebsmodel.xml.schemas.kontekst.x2007.x05.x31.HovedOplysningerDocument;
import dk.skat.begrebsmodel.xml.schemas.kontekst.x2007.x05.x31.HovedOplysningerType;

import java.net.InetAddress;
import java.util.Calendar;
import java.util.Date;
import java.util.UUID;

/**
 * Factory class to create a <code>HovedOplysningerDocument</code>.
 * <p/>
 *
 * @author Christopher Derek Curry (cdcurry@krispoint.com)
 * @since 1.0
 */
public class HovedOplysningerDocumentFactory {


    public static HovedOplysningerDocument getHovedOplysningerDocument(String userCode, String roleCode, String locationCode) {
        HovedOplysningerDocument hovedOplysningerDoc;
        hovedOplysningerDoc = HovedOplysningerDocument.Factory.newInstance();
        HovedOplysningerType hovedOplysningerType = hovedOplysningerDoc
                .addNewHovedOplysninger();
        String txId = generateId();
        hovedOplysningerType.setTransaktionsID(txId);
        hovedOplysningerType.setTestmode(false);
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(new Date());
        hovedOplysningerType.setTransaktionsTid(calendar);
        hovedOplysningerType.setBrugerKode(userCode);
        hovedOplysningerType.setRolleKode(roleCode);
        hovedOplysningerType.setStedKode(locationCode);
        return hovedOplysningerDoc;
    }

    public static String generateId() {
        return UUID.randomUUID().toString().concat(getSuffix());
    }

    private static String suffix = null;

    private static String getSuffix() {
        if (suffix == null) {
            try {
                suffix = InetAddress.getLocalHost().getHostName();
            } catch (Exception e) {
                suffix = "Hostname_unresolveable";
            }
        }
        return suffix;
    }

}
