package dk.skat.security.providers.validators;

import dk.skat.begrebsmodel.x2009.x01.x15.*;
import dk.skat.ics.security.*;
import dk.skat.security.providers.atn.HovedOplysningerDocumentFactory;
import weblogic.logging.NonCatalogLogger;

import javax.xml.rpc.ServiceException;
import java.rmi.RemoteException;
import java.util.List;

/**
 *
 */
public class VirksomhedValidator {

    /**
     * Logger
     */
    private final static NonCatalogLogger logger = new NonCatalogLogger(VirksomhedValidator.class.getName());

    public static boolean validateCVRNumber(String cvr, String endPoint) {
        // Assume false.
        boolean result = false;

        try {
            EORIVirksomhedValiderService service = new EORIVirksomhedValiderService_Impl(endPoint);
            EORIVirksomhedValiderServicePortType port = service.getEORIVirksomhedValiderServicePortType();
            EORIVirksomhedValiderIDocument eoriVirksomhedValiderIDocument = EORIVirksomhedValiderIDocument.Factory.newInstance();

            EORIVirksomhedValiderIDocument.EORIVirksomhedValiderI eoriVirksomhedValiderI =
                    eoriVirksomhedValiderIDocument.addNewEORIVirksomhedValiderI();

            EORIVirksomhedValiderIType.SECVRNummer secvrNummer = EORIVirksomhedValiderIType.SECVRNummer.Factory.newInstance();
            SENummerType seNummerType = secvrNummer.addNewVirksomhedSENummer();
            seNummerType.setStringValue(cvr);
            eoriVirksomhedValiderI.setSECVRNummer(secvrNummer);
            KontekstType kontekstTypeInput = KontekstType.Factory.parse(
                    HovedOplysningerDocumentFactory.getHovedOplysningerDocument("ICSAuthenticationProvider",
                            "SecurityProvider", "SecurityProvider").toString());
            eoriVirksomhedValiderI.setKontekst(kontekstTypeInput);
            logger.debug("INPUT: " + eoriVirksomhedValiderIDocument);
            EORIVirksomhedValiderODocument output = port.getEORIVirksomhedValider(eoriVirksomhedValiderIDocument);
            logger.debug("OUTPUT: " + output);
            if (output.getEORIVirksomhedValiderO() != null) {
                EORIVirksomhedValiderOType.EORIVirksomhedValiderSvarListe liste =
                        output.getEORIVirksomhedValiderO().getEORIVirksomhedValiderSvarListe();

                List<EORIVirksomhedValiderOType.EORIVirksomhedValiderSvarListe.EORIVirksomhedValiderSvar> svarListe =
                        liste.getEORIVirksomhedValiderSvarList();
                if (svarListe != null && svarListe.size() == 1) {
                    return svarListe.get(0).getEORIErValid();
                }
            }

        } catch (RemoteException e) {
                 logger.error("Error while validating CVR number. Will validate to false.", e);
             } catch (ServiceException e2) {
                 logger.error("Error while validating CVR number. Will validate to false.", e2);
             } catch (Exception e3) {
                 logger.error("Error while validating CVR number. Will validate to false.", e3);
             }
        return result;
    }

}
